/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -c Systemd1Manager -p /build/deepin-session/src/dde-session/dbusinterface/org_freedesktop_systemd1_Manager /build/deepin-session/src/dde-session/dbus/interface/org.freedesktop.systemd1.Manager.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_FREEDESKTOP_SYSTEMD1_MANAGER_H
#define ORG_FREEDESKTOP_SYSTEMD1_MANAGER_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>

#include "types/stringstructlist.h"

/*
 * Proxy class for interface org.freedesktop.systemd1.Manager
 */
class __Systemd1ManagerPrivate;
class __Systemd1Manager : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.systemd1.Manager"; }

public:
    explicit __Systemd1Manager(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__Systemd1Manager();

    Q_PROPERTY(QString Architecture READ architecture NOTIFY ArchitectureChanged)
    QString architecture();

    Q_PROPERTY(bool ConfirmSpawn READ confirmSpawn NOTIFY ConfirmSpawnChanged)
    bool confirmSpawn();

    Q_PROPERTY(QString ControlGroup READ controlGroup NOTIFY ControlGroupChanged)
    QString controlGroup();

    Q_PROPERTY(bool DefaultBlockIOAccounting READ defaultBlockIOAccounting NOTIFY DefaultBlockIOAccountingChanged)
    bool defaultBlockIOAccounting();

    Q_PROPERTY(bool DefaultCPUAccounting READ defaultCPUAccounting NOTIFY DefaultCPUAccountingChanged)
    bool defaultCPUAccounting();

    Q_PROPERTY(qulonglong DefaultLimitAS READ defaultLimitAS NOTIFY DefaultLimitASChanged)
    qulonglong defaultLimitAS();

    Q_PROPERTY(qulonglong DefaultLimitASSoft READ defaultLimitASSoft NOTIFY DefaultLimitASSoftChanged)
    qulonglong defaultLimitASSoft();

    Q_PROPERTY(qulonglong DefaultLimitCORE READ defaultLimitCORE NOTIFY DefaultLimitCOREChanged)
    qulonglong defaultLimitCORE();

    Q_PROPERTY(qulonglong DefaultLimitCORESoft READ defaultLimitCORESoft NOTIFY DefaultLimitCORESoftChanged)
    qulonglong defaultLimitCORESoft();

    Q_PROPERTY(qulonglong DefaultLimitCPU READ defaultLimitCPU NOTIFY DefaultLimitCPUChanged)
    qulonglong defaultLimitCPU();

    Q_PROPERTY(qulonglong DefaultLimitCPUSoft READ defaultLimitCPUSoft NOTIFY DefaultLimitCPUSoftChanged)
    qulonglong defaultLimitCPUSoft();

    Q_PROPERTY(qulonglong DefaultLimitDATA READ defaultLimitDATA NOTIFY DefaultLimitDATAChanged)
    qulonglong defaultLimitDATA();

    Q_PROPERTY(qulonglong DefaultLimitDATASoft READ defaultLimitDATASoft NOTIFY DefaultLimitDATASoftChanged)
    qulonglong defaultLimitDATASoft();

    Q_PROPERTY(qulonglong DefaultLimitFSIZE READ defaultLimitFSIZE NOTIFY DefaultLimitFSIZEChanged)
    qulonglong defaultLimitFSIZE();

    Q_PROPERTY(qulonglong DefaultLimitFSIZESoft READ defaultLimitFSIZESoft NOTIFY DefaultLimitFSIZESoftChanged)
    qulonglong defaultLimitFSIZESoft();

    Q_PROPERTY(qulonglong DefaultLimitLOCKS READ defaultLimitLOCKS NOTIFY DefaultLimitLOCKSChanged)
    qulonglong defaultLimitLOCKS();

    Q_PROPERTY(qulonglong DefaultLimitLOCKSSoft READ defaultLimitLOCKSSoft NOTIFY DefaultLimitLOCKSSoftChanged)
    qulonglong defaultLimitLOCKSSoft();

    Q_PROPERTY(qulonglong DefaultLimitMEMLOCK READ defaultLimitMEMLOCK NOTIFY DefaultLimitMEMLOCKChanged)
    qulonglong defaultLimitMEMLOCK();

    Q_PROPERTY(qulonglong DefaultLimitMEMLOCKSoft READ defaultLimitMEMLOCKSoft NOTIFY DefaultLimitMEMLOCKSoftChanged)
    qulonglong defaultLimitMEMLOCKSoft();

    Q_PROPERTY(qulonglong DefaultLimitMSGQUEUE READ defaultLimitMSGQUEUE NOTIFY DefaultLimitMSGQUEUEChanged)
    qulonglong defaultLimitMSGQUEUE();

    Q_PROPERTY(qulonglong DefaultLimitMSGQUEUESoft READ defaultLimitMSGQUEUESoft NOTIFY DefaultLimitMSGQUEUESoftChanged)
    qulonglong defaultLimitMSGQUEUESoft();

    Q_PROPERTY(qulonglong DefaultLimitNICE READ defaultLimitNICE NOTIFY DefaultLimitNICEChanged)
    qulonglong defaultLimitNICE();

    Q_PROPERTY(qulonglong DefaultLimitNICESoft READ defaultLimitNICESoft NOTIFY DefaultLimitNICESoftChanged)
    qulonglong defaultLimitNICESoft();

    Q_PROPERTY(qulonglong DefaultLimitNOFILE READ defaultLimitNOFILE NOTIFY DefaultLimitNOFILEChanged)
    qulonglong defaultLimitNOFILE();

    Q_PROPERTY(qulonglong DefaultLimitNOFILESoft READ defaultLimitNOFILESoft NOTIFY DefaultLimitNOFILESoftChanged)
    qulonglong defaultLimitNOFILESoft();

    Q_PROPERTY(qulonglong DefaultLimitNPROC READ defaultLimitNPROC NOTIFY DefaultLimitNPROCChanged)
    qulonglong defaultLimitNPROC();

    Q_PROPERTY(qulonglong DefaultLimitNPROCSoft READ defaultLimitNPROCSoft NOTIFY DefaultLimitNPROCSoftChanged)
    qulonglong defaultLimitNPROCSoft();

    Q_PROPERTY(qulonglong DefaultLimitRSS READ defaultLimitRSS NOTIFY DefaultLimitRSSChanged)
    qulonglong defaultLimitRSS();

    Q_PROPERTY(qulonglong DefaultLimitRSSSoft READ defaultLimitRSSSoft NOTIFY DefaultLimitRSSSoftChanged)
    qulonglong defaultLimitRSSSoft();

    Q_PROPERTY(qulonglong DefaultLimitRTPRIO READ defaultLimitRTPRIO NOTIFY DefaultLimitRTPRIOChanged)
    qulonglong defaultLimitRTPRIO();

    Q_PROPERTY(qulonglong DefaultLimitRTPRIOSoft READ defaultLimitRTPRIOSoft NOTIFY DefaultLimitRTPRIOSoftChanged)
    qulonglong defaultLimitRTPRIOSoft();

    Q_PROPERTY(qulonglong DefaultLimitRTTIME READ defaultLimitRTTIME NOTIFY DefaultLimitRTTIMEChanged)
    qulonglong defaultLimitRTTIME();

    Q_PROPERTY(qulonglong DefaultLimitRTTIMESoft READ defaultLimitRTTIMESoft NOTIFY DefaultLimitRTTIMESoftChanged)
    qulonglong defaultLimitRTTIMESoft();

    Q_PROPERTY(qulonglong DefaultLimitSIGPENDING READ defaultLimitSIGPENDING NOTIFY DefaultLimitSIGPENDINGChanged)
    qulonglong defaultLimitSIGPENDING();

    Q_PROPERTY(qulonglong DefaultLimitSIGPENDINGSoft READ defaultLimitSIGPENDINGSoft NOTIFY DefaultLimitSIGPENDINGSoftChanged)
    qulonglong defaultLimitSIGPENDINGSoft();

    Q_PROPERTY(qulonglong DefaultLimitSTACK READ defaultLimitSTACK NOTIFY DefaultLimitSTACKChanged)
    qulonglong defaultLimitSTACK();

    Q_PROPERTY(qulonglong DefaultLimitSTACKSoft READ defaultLimitSTACKSoft NOTIFY DefaultLimitSTACKSoftChanged)
    qulonglong defaultLimitSTACKSoft();

    Q_PROPERTY(bool DefaultMemoryAccounting READ defaultMemoryAccounting NOTIFY DefaultMemoryAccountingChanged)
    bool defaultMemoryAccounting();

    Q_PROPERTY(qulonglong DefaultRestartUSec READ defaultRestartUSec NOTIFY DefaultRestartUSecChanged)
    qulonglong defaultRestartUSec();

    Q_PROPERTY(QString DefaultStandardError READ defaultStandardError NOTIFY DefaultStandardErrorChanged)
    QString defaultStandardError();

    Q_PROPERTY(QString DefaultStandardOutput READ defaultStandardOutput NOTIFY DefaultStandardOutputChanged)
    QString defaultStandardOutput();

    Q_PROPERTY(uint DefaultStartLimitBurst READ defaultStartLimitBurst NOTIFY DefaultStartLimitBurstChanged)
    uint defaultStartLimitBurst();

    Q_PROPERTY(qulonglong DefaultStartLimitIntervalUSec READ defaultStartLimitIntervalUSec NOTIFY DefaultStartLimitIntervalUSecChanged)
    qulonglong defaultStartLimitIntervalUSec();

    Q_PROPERTY(bool DefaultTasksAccounting READ defaultTasksAccounting NOTIFY DefaultTasksAccountingChanged)
    bool defaultTasksAccounting();

    Q_PROPERTY(qulonglong DefaultTasksMax READ defaultTasksMax NOTIFY DefaultTasksMaxChanged)
    qulonglong defaultTasksMax();

    Q_PROPERTY(qulonglong DefaultTimeoutStartUSec READ defaultTimeoutStartUSec NOTIFY DefaultTimeoutStartUSecChanged)
    qulonglong defaultTimeoutStartUSec();

    Q_PROPERTY(qulonglong DefaultTimeoutStopUSec READ defaultTimeoutStopUSec NOTIFY DefaultTimeoutStopUSecChanged)
    qulonglong defaultTimeoutStopUSec();

    Q_PROPERTY(qulonglong DefaultTimerAccuracyUSec READ defaultTimerAccuracyUSec NOTIFY DefaultTimerAccuracyUSecChanged)
    qulonglong defaultTimerAccuracyUSec();

    Q_PROPERTY(QStringList Environment READ environment NOTIFY EnvironmentChanged)
    QStringList environment();

    Q_PROPERTY(uchar ExitCode READ exitCode NOTIFY ExitCodeChanged)
    uchar exitCode();

    Q_PROPERTY(QString Features READ features NOTIFY FeaturesChanged)
    QString features();

    Q_PROPERTY(qulonglong FinishTimestamp READ finishTimestamp NOTIFY FinishTimestampChanged)
    qulonglong finishTimestamp();

    Q_PROPERTY(qulonglong FinishTimestampMonotonic READ finishTimestampMonotonic NOTIFY FinishTimestampMonotonicChanged)
    qulonglong finishTimestampMonotonic();

    Q_PROPERTY(qulonglong FirmwareTimestamp READ firmwareTimestamp NOTIFY FirmwareTimestampChanged)
    qulonglong firmwareTimestamp();

    Q_PROPERTY(qulonglong FirmwareTimestampMonotonic READ firmwareTimestampMonotonic NOTIFY FirmwareTimestampMonotonicChanged)
    qulonglong firmwareTimestampMonotonic();

    Q_PROPERTY(qulonglong GeneratorsFinishTimestamp READ generatorsFinishTimestamp NOTIFY GeneratorsFinishTimestampChanged)
    qulonglong generatorsFinishTimestamp();

    Q_PROPERTY(qulonglong GeneratorsFinishTimestampMonotonic READ generatorsFinishTimestampMonotonic NOTIFY GeneratorsFinishTimestampMonotonicChanged)
    qulonglong generatorsFinishTimestampMonotonic();

    Q_PROPERTY(qulonglong GeneratorsStartTimestamp READ generatorsStartTimestamp NOTIFY GeneratorsStartTimestampChanged)
    qulonglong generatorsStartTimestamp();

    Q_PROPERTY(qulonglong GeneratorsStartTimestampMonotonic READ generatorsStartTimestampMonotonic NOTIFY GeneratorsStartTimestampMonotonicChanged)
    qulonglong generatorsStartTimestampMonotonic();

    Q_PROPERTY(qulonglong InitRDGeneratorsFinishTimestamp READ initRDGeneratorsFinishTimestamp NOTIFY InitRDGeneratorsFinishTimestampChanged)
    qulonglong initRDGeneratorsFinishTimestamp();

    Q_PROPERTY(qulonglong InitRDGeneratorsFinishTimestampMonotonic READ initRDGeneratorsFinishTimestampMonotonic NOTIFY InitRDGeneratorsFinishTimestampMonotonicChanged)
    qulonglong initRDGeneratorsFinishTimestampMonotonic();

    Q_PROPERTY(qulonglong InitRDGeneratorsStartTimestamp READ initRDGeneratorsStartTimestamp NOTIFY InitRDGeneratorsStartTimestampChanged)
    qulonglong initRDGeneratorsStartTimestamp();

    Q_PROPERTY(qulonglong InitRDGeneratorsStartTimestampMonotonic READ initRDGeneratorsStartTimestampMonotonic NOTIFY InitRDGeneratorsStartTimestampMonotonicChanged)
    qulonglong initRDGeneratorsStartTimestampMonotonic();

    Q_PROPERTY(qulonglong InitRDSecurityFinishTimestamp READ initRDSecurityFinishTimestamp NOTIFY InitRDSecurityFinishTimestampChanged)
    qulonglong initRDSecurityFinishTimestamp();

    Q_PROPERTY(qulonglong InitRDSecurityFinishTimestampMonotonic READ initRDSecurityFinishTimestampMonotonic NOTIFY InitRDSecurityFinishTimestampMonotonicChanged)
    qulonglong initRDSecurityFinishTimestampMonotonic();

    Q_PROPERTY(qulonglong InitRDSecurityStartTimestamp READ initRDSecurityStartTimestamp NOTIFY InitRDSecurityStartTimestampChanged)
    qulonglong initRDSecurityStartTimestamp();

    Q_PROPERTY(qulonglong InitRDSecurityStartTimestampMonotonic READ initRDSecurityStartTimestampMonotonic NOTIFY InitRDSecurityStartTimestampMonotonicChanged)
    qulonglong initRDSecurityStartTimestampMonotonic();

    Q_PROPERTY(qulonglong InitRDTimestamp READ initRDTimestamp NOTIFY InitRDTimestampChanged)
    qulonglong initRDTimestamp();

    Q_PROPERTY(qulonglong InitRDTimestampMonotonic READ initRDTimestampMonotonic NOTIFY InitRDTimestampMonotonicChanged)
    qulonglong initRDTimestampMonotonic();

    Q_PROPERTY(qulonglong InitRDUnitsLoadFinishTimestamp READ initRDUnitsLoadFinishTimestamp NOTIFY InitRDUnitsLoadFinishTimestampChanged)
    qulonglong initRDUnitsLoadFinishTimestamp();

    Q_PROPERTY(qulonglong InitRDUnitsLoadFinishTimestampMonotonic READ initRDUnitsLoadFinishTimestampMonotonic NOTIFY InitRDUnitsLoadFinishTimestampMonotonicChanged)
    qulonglong initRDUnitsLoadFinishTimestampMonotonic();

    Q_PROPERTY(qulonglong InitRDUnitsLoadStartTimestamp READ initRDUnitsLoadStartTimestamp NOTIFY InitRDUnitsLoadStartTimestampChanged)
    qulonglong initRDUnitsLoadStartTimestamp();

    Q_PROPERTY(qulonglong InitRDUnitsLoadStartTimestampMonotonic READ initRDUnitsLoadStartTimestampMonotonic NOTIFY InitRDUnitsLoadStartTimestampMonotonicChanged)
    qulonglong initRDUnitsLoadStartTimestampMonotonic();

    Q_PROPERTY(qulonglong KernelTimestamp READ kernelTimestamp NOTIFY KernelTimestampChanged)
    qulonglong kernelTimestamp();

    Q_PROPERTY(qulonglong KernelTimestampMonotonic READ kernelTimestampMonotonic NOTIFY KernelTimestampMonotonicChanged)
    qulonglong kernelTimestampMonotonic();

    Q_PROPERTY(qulonglong LoaderTimestamp READ loaderTimestamp NOTIFY LoaderTimestampChanged)
    qulonglong loaderTimestamp();

    Q_PROPERTY(qulonglong LoaderTimestampMonotonic READ loaderTimestampMonotonic NOTIFY LoaderTimestampMonotonicChanged)
    qulonglong loaderTimestampMonotonic();

    Q_PROPERTY(QString LogLevel READ logLevel WRITE setLogLevel NOTIFY LogLevelChanged)
    QString logLevel();
    void setLogLevel(const QString &value);

    Q_PROPERTY(QString LogTarget READ logTarget WRITE setLogTarget NOTIFY LogTargetChanged)
    QString logTarget();
    void setLogTarget(const QString &value);

    Q_PROPERTY(uint NFailedJobs READ nFailedJobs NOTIFY NFailedJobsChanged)
    uint nFailedJobs();

    Q_PROPERTY(uint NFailedUnits READ nFailedUnits NOTIFY NFailedUnitsChanged)
    uint nFailedUnits();

    Q_PROPERTY(uint NInstalledJobs READ nInstalledJobs NOTIFY NInstalledJobsChanged)
    uint nInstalledJobs();

    Q_PROPERTY(uint NJobs READ nJobs NOTIFY NJobsChanged)
    uint nJobs();

    Q_PROPERTY(uint NNames READ nNames NOTIFY NNamesChanged)
    uint nNames();

    Q_PROPERTY(double Progress READ progress NOTIFY ProgressChanged)
    double progress();

    Q_PROPERTY(qulonglong RuntimeWatchdogUSec READ runtimeWatchdogUSec WRITE setRuntimeWatchdogUSec NOTIFY RuntimeWatchdogUSecChanged)
    qulonglong runtimeWatchdogUSec();
    void setRuntimeWatchdogUSec(qulonglong value);

    Q_PROPERTY(qulonglong SecurityFinishTimestamp READ securityFinishTimestamp NOTIFY SecurityFinishTimestampChanged)
    qulonglong securityFinishTimestamp();

    Q_PROPERTY(qulonglong SecurityFinishTimestampMonotonic READ securityFinishTimestampMonotonic NOTIFY SecurityFinishTimestampMonotonicChanged)
    qulonglong securityFinishTimestampMonotonic();

    Q_PROPERTY(qulonglong SecurityStartTimestamp READ securityStartTimestamp NOTIFY SecurityStartTimestampChanged)
    qulonglong securityStartTimestamp();

    Q_PROPERTY(qulonglong SecurityStartTimestampMonotonic READ securityStartTimestampMonotonic NOTIFY SecurityStartTimestampMonotonicChanged)
    qulonglong securityStartTimestampMonotonic();

    Q_PROPERTY(bool ServiceWatchdogs READ serviceWatchdogs WRITE setServiceWatchdogs NOTIFY ServiceWatchdogsChanged)
    bool serviceWatchdogs();
    void setServiceWatchdogs(bool value);

    Q_PROPERTY(bool ShowStatus READ showStatus NOTIFY ShowStatusChanged)
    bool showStatus();

    Q_PROPERTY(qulonglong ShutdownWatchdogUSec READ shutdownWatchdogUSec WRITE setShutdownWatchdogUSec NOTIFY ShutdownWatchdogUSecChanged)
    qulonglong shutdownWatchdogUSec();
    void setShutdownWatchdogUSec(qulonglong value);

    Q_PROPERTY(QString SystemState READ systemState NOTIFY SystemStateChanged)
    QString systemState();

    Q_PROPERTY(QString Tainted READ tainted NOTIFY TaintedChanged)
    QString tainted();

    Q_PROPERTY(qulonglong TimerSlackNSec READ timerSlackNSec NOTIFY TimerSlackNSecChanged)
    qulonglong timerSlackNSec();

    Q_PROPERTY(QStringList UnitPath READ unitPath NOTIFY UnitPathChanged)
    QStringList unitPath();

    Q_PROPERTY(qulonglong UnitsLoadFinishTimestamp READ unitsLoadFinishTimestamp NOTIFY UnitsLoadFinishTimestampChanged)
    qulonglong unitsLoadFinishTimestamp();

    Q_PROPERTY(qulonglong UnitsLoadFinishTimestampMonotonic READ unitsLoadFinishTimestampMonotonic NOTIFY UnitsLoadFinishTimestampMonotonicChanged)
    qulonglong unitsLoadFinishTimestampMonotonic();

    Q_PROPERTY(qulonglong UnitsLoadStartTimestamp READ unitsLoadStartTimestamp NOTIFY UnitsLoadStartTimestampChanged)
    qulonglong unitsLoadStartTimestamp();

    Q_PROPERTY(qulonglong UnitsLoadStartTimestampMonotonic READ unitsLoadStartTimestampMonotonic NOTIFY UnitsLoadStartTimestampMonotonicChanged)
    qulonglong unitsLoadStartTimestampMonotonic();

    Q_PROPERTY(qulonglong UserspaceTimestamp READ userspaceTimestamp NOTIFY UserspaceTimestampChanged)
    qulonglong userspaceTimestamp();

    Q_PROPERTY(qulonglong UserspaceTimestampMonotonic READ userspaceTimestampMonotonic NOTIFY UserspaceTimestampMonotonicChanged)
    qulonglong userspaceTimestampMonotonic();

    Q_PROPERTY(QString Version READ version NOTIFY VersionChanged)
    QString version();

    Q_PROPERTY(QString Virtualization READ virtualization NOTIFY VirtualizationChanged)
    QString virtualization();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> AbandonScope(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("AbandonScope"), argumentList);
    }

    inline void AbandonScopeQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("AbandonScope"), argumentList);
    }


    inline QDBusPendingReply<QString> Dump()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Dump"), argumentList);
    }



    inline QDBusPendingReply<QDBusUnixFileDescriptor> DumpByFileDescriptor()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("DumpByFileDescriptor"), argumentList);
    }



    inline QDBusPendingReply<> Exit()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Exit"), argumentList);
    }

    inline void ExitQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Exit"), argumentList);
    }


    inline QDBusPendingReply<QDBusObjectPath> GetJob(uint in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetJob"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> GetUnit(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetUnit"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> GetUnitByControlGroup(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetUnitByControlGroup"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> GetUnitByInvocationID(const QByteArray &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetUnitByInvocationID"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> GetUnitByPID(uint in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetUnitByPID"), argumentList);
    }



    inline QDBusPendingReply<QStringList> GetUnitFileLinks(const QString &in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("GetUnitFileLinks"), argumentList);
    }



    inline QDBusPendingReply<QString> GetUnitFileState(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("GetUnitFileState"), argumentList);
    }



    inline QDBusPendingReply<> Halt()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Halt"), argumentList);
    }

    inline void HaltQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Halt"), argumentList);
    }


    inline QDBusPendingReply<> KExec()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("KExec"), argumentList);
    }

    inline void KExecQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("KExec"), argumentList);
    }


    inline QDBusPendingReply<> KillUnit(const QString &in0, const QString &in1, int in2)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2);
        return asyncCallWithArgumentList(QStringLiteral("KillUnit"), argumentList);
    }

    inline void KillUnitQueued(const QString &in0, const QString &in1, int in2)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2);

        CallQueued(QStringLiteral("KillUnit"), argumentList);
    }


    inline QDBusPendingReply<QDBusObjectPath> LoadUnit(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("LoadUnit"), argumentList);
    }



    inline QDBusPendingReply<uint> LookupDynamicUserByName(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("LookupDynamicUserByName"), argumentList);
    }



    inline QDBusPendingReply<QString> LookupDynamicUserByUID(uint in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("LookupDynamicUserByUID"), argumentList);
    }



    inline QDBusPendingReply<StringStructList> MaskUnitFiles(const QStringList &in0, bool in1, bool in2)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2);
        return asyncCallWithArgumentList(QStringLiteral("MaskUnitFiles"), argumentList);
    }



    inline QDBusPendingReply<> PowerOff()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("PowerOff"), argumentList);
    }

    inline void PowerOffQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("PowerOff"), argumentList);
    }


    inline QDBusPendingReply<> Reboot()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Reboot"), argumentList);
    }

    inline void RebootQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Reboot"), argumentList);
    }


    inline QDBusPendingReply<> Reexecute()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Reexecute"), argumentList);
    }

    inline void ReexecuteQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Reexecute"), argumentList);
    }


    inline QDBusPendingReply<> RefUnit(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("RefUnit"), argumentList);
    }

    inline void RefUnitQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("RefUnit"), argumentList);
    }


    inline QDBusPendingReply<> Reload()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Reload"), argumentList);
    }

    inline void ReloadQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Reload"), argumentList);
    }


    inline QDBusPendingReply<QDBusObjectPath> ReloadOrRestartUnit(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("ReloadOrRestartUnit"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> ReloadOrTryRestartUnit(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("ReloadOrTryRestartUnit"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> ReloadUnit(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("ReloadUnit"), argumentList);
    }



    inline QDBusPendingReply<> ResetFailedUnit(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("ResetFailedUnit"), argumentList);
    }

    inline void ResetFailedUnitQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("ResetFailedUnit"), argumentList);
    }


    inline QDBusPendingReply<QDBusObjectPath> RestartUnit(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("RestartUnit"), argumentList);
    }



    inline QDBusPendingReply<> SetEnvironment(const QStringList &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetEnvironment"), argumentList);
    }

    inline void SetEnvironmentQueued(const QStringList &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetEnvironment"), argumentList);
    }


    inline QDBusPendingReply<> SetExitCode(uchar in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetExitCode"), argumentList);
    }

    inline void SetExitCodeQueued(uchar in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetExitCode"), argumentList);
    }


    inline QDBusPendingReply<QDBusObjectPath> StartUnit(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("StartUnit"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> StartUnitReplace(const QString &in0, const QString &in1, const QString &in2)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1) << QVariant::fromValue(in2);
        return asyncCallWithArgumentList(QStringLiteral("StartUnitReplace"), argumentList);
    }



    inline QDBusPendingReply<QDBusObjectPath> StopUnit(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("StopUnit"), argumentList);
    }



    inline QDBusPendingReply<> Subscribe()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Subscribe"), argumentList);
    }

    inline void SubscribeQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Subscribe"), argumentList);
    }


    inline QDBusPendingReply<> SwitchRoot(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("SwitchRoot"), argumentList);
    }

    inline void SwitchRootQueued(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("SwitchRoot"), argumentList);
    }


    inline QDBusPendingReply<QDBusObjectPath> TryRestartUnit(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("TryRestartUnit"), argumentList);
    }



    inline QDBusPendingReply<StringStructList> UnmaskUnitFiles(const QStringList &in0, bool in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("UnmaskUnitFiles"), argumentList);
    }



    inline QDBusPendingReply<> UnrefUnit(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("UnrefUnit"), argumentList);
    }

    inline void UnrefUnitQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("UnrefUnit"), argumentList);
    }


    inline QDBusPendingReply<> UnsetAndSetEnvironment(const QStringList &in0, const QStringList &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("UnsetAndSetEnvironment"), argumentList);
    }

    inline void UnsetAndSetEnvironmentQueued(const QStringList &in0, const QStringList &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("UnsetAndSetEnvironment"), argumentList);
    }


    inline QDBusPendingReply<> UnsetEnvironment(const QStringList &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("UnsetEnvironment"), argumentList);
    }

    inline void UnsetEnvironmentQueued(const QStringList &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("UnsetEnvironment"), argumentList);
    }


    inline QDBusPendingReply<> Unsubscribe()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Unsubscribe"), argumentList);
    }

    inline void UnsubscribeQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Unsubscribe"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    void JobNew(uint in0, const QDBusObjectPath &in1, const QString &in2);
    void JobRemoved(uint in0, const QDBusObjectPath &in1, const QString &in2, const QString &in3);
    void Reloading(bool in0);
    void StartupFinished(qulonglong in0, qulonglong in1, qulonglong in2, qulonglong in3, qulonglong in4, qulonglong in5);
    void UnitFilesChanged();
    void UnitNew(const QString &in0, const QDBusObjectPath &in1);
    void UnitRemoved(const QString &in0, const QDBusObjectPath &in1);
    // begin property changed signals
    void ArchitectureChanged(const QString & value) const;
    void ConfirmSpawnChanged(bool  value) const;
    void ControlGroupChanged(const QString & value) const;
    void DefaultBlockIOAccountingChanged(bool  value) const;
    void DefaultCPUAccountingChanged(bool  value) const;
    void DefaultLimitASChanged(qulonglong  value) const;
    void DefaultLimitASSoftChanged(qulonglong  value) const;
    void DefaultLimitCOREChanged(qulonglong  value) const;
    void DefaultLimitCORESoftChanged(qulonglong  value) const;
    void DefaultLimitCPUChanged(qulonglong  value) const;
    void DefaultLimitCPUSoftChanged(qulonglong  value) const;
    void DefaultLimitDATAChanged(qulonglong  value) const;
    void DefaultLimitDATASoftChanged(qulonglong  value) const;
    void DefaultLimitFSIZEChanged(qulonglong  value) const;
    void DefaultLimitFSIZESoftChanged(qulonglong  value) const;
    void DefaultLimitLOCKSChanged(qulonglong  value) const;
    void DefaultLimitLOCKSSoftChanged(qulonglong  value) const;
    void DefaultLimitMEMLOCKChanged(qulonglong  value) const;
    void DefaultLimitMEMLOCKSoftChanged(qulonglong  value) const;
    void DefaultLimitMSGQUEUEChanged(qulonglong  value) const;
    void DefaultLimitMSGQUEUESoftChanged(qulonglong  value) const;
    void DefaultLimitNICEChanged(qulonglong  value) const;
    void DefaultLimitNICESoftChanged(qulonglong  value) const;
    void DefaultLimitNOFILEChanged(qulonglong  value) const;
    void DefaultLimitNOFILESoftChanged(qulonglong  value) const;
    void DefaultLimitNPROCChanged(qulonglong  value) const;
    void DefaultLimitNPROCSoftChanged(qulonglong  value) const;
    void DefaultLimitRSSChanged(qulonglong  value) const;
    void DefaultLimitRSSSoftChanged(qulonglong  value) const;
    void DefaultLimitRTPRIOChanged(qulonglong  value) const;
    void DefaultLimitRTPRIOSoftChanged(qulonglong  value) const;
    void DefaultLimitRTTIMEChanged(qulonglong  value) const;
    void DefaultLimitRTTIMESoftChanged(qulonglong  value) const;
    void DefaultLimitSIGPENDINGChanged(qulonglong  value) const;
    void DefaultLimitSIGPENDINGSoftChanged(qulonglong  value) const;
    void DefaultLimitSTACKChanged(qulonglong  value) const;
    void DefaultLimitSTACKSoftChanged(qulonglong  value) const;
    void DefaultMemoryAccountingChanged(bool  value) const;
    void DefaultRestartUSecChanged(qulonglong  value) const;
    void DefaultStandardErrorChanged(const QString & value) const;
    void DefaultStandardOutputChanged(const QString & value) const;
    void DefaultStartLimitBurstChanged(uint  value) const;
    void DefaultStartLimitIntervalUSecChanged(qulonglong  value) const;
    void DefaultTasksAccountingChanged(bool  value) const;
    void DefaultTasksMaxChanged(qulonglong  value) const;
    void DefaultTimeoutStartUSecChanged(qulonglong  value) const;
    void DefaultTimeoutStopUSecChanged(qulonglong  value) const;
    void DefaultTimerAccuracyUSecChanged(qulonglong  value) const;
    void EnvironmentChanged(const QStringList & value) const;
    void ExitCodeChanged(uchar  value) const;
    void FeaturesChanged(const QString & value) const;
    void FinishTimestampChanged(qulonglong  value) const;
    void FinishTimestampMonotonicChanged(qulonglong  value) const;
    void FirmwareTimestampChanged(qulonglong  value) const;
    void FirmwareTimestampMonotonicChanged(qulonglong  value) const;
    void GeneratorsFinishTimestampChanged(qulonglong  value) const;
    void GeneratorsFinishTimestampMonotonicChanged(qulonglong  value) const;
    void GeneratorsStartTimestampChanged(qulonglong  value) const;
    void GeneratorsStartTimestampMonotonicChanged(qulonglong  value) const;
    void InitRDGeneratorsFinishTimestampChanged(qulonglong  value) const;
    void InitRDGeneratorsFinishTimestampMonotonicChanged(qulonglong  value) const;
    void InitRDGeneratorsStartTimestampChanged(qulonglong  value) const;
    void InitRDGeneratorsStartTimestampMonotonicChanged(qulonglong  value) const;
    void InitRDSecurityFinishTimestampChanged(qulonglong  value) const;
    void InitRDSecurityFinishTimestampMonotonicChanged(qulonglong  value) const;
    void InitRDSecurityStartTimestampChanged(qulonglong  value) const;
    void InitRDSecurityStartTimestampMonotonicChanged(qulonglong  value) const;
    void InitRDTimestampChanged(qulonglong  value) const;
    void InitRDTimestampMonotonicChanged(qulonglong  value) const;
    void InitRDUnitsLoadFinishTimestampChanged(qulonglong  value) const;
    void InitRDUnitsLoadFinishTimestampMonotonicChanged(qulonglong  value) const;
    void InitRDUnitsLoadStartTimestampChanged(qulonglong  value) const;
    void InitRDUnitsLoadStartTimestampMonotonicChanged(qulonglong  value) const;
    void KernelTimestampChanged(qulonglong  value) const;
    void KernelTimestampMonotonicChanged(qulonglong  value) const;
    void LoaderTimestampChanged(qulonglong  value) const;
    void LoaderTimestampMonotonicChanged(qulonglong  value) const;
    void LogLevelChanged(const QString & value) const;
    void LogTargetChanged(const QString & value) const;
    void NFailedJobsChanged(uint  value) const;
    void NFailedUnitsChanged(uint  value) const;
    void NInstalledJobsChanged(uint  value) const;
    void NJobsChanged(uint  value) const;
    void NNamesChanged(uint  value) const;
    void ProgressChanged(double  value) const;
    void RuntimeWatchdogUSecChanged(qulonglong  value) const;
    void SecurityFinishTimestampChanged(qulonglong  value) const;
    void SecurityFinishTimestampMonotonicChanged(qulonglong  value) const;
    void SecurityStartTimestampChanged(qulonglong  value) const;
    void SecurityStartTimestampMonotonicChanged(qulonglong  value) const;
    void ServiceWatchdogsChanged(bool  value) const;
    void ShowStatusChanged(bool  value) const;
    void ShutdownWatchdogUSecChanged(qulonglong  value) const;
    void SystemStateChanged(const QString & value) const;
    void TaintedChanged(const QString & value) const;
    void TimerSlackNSecChanged(qulonglong  value) const;
    void UnitPathChanged(const QStringList & value) const;
    void UnitsLoadFinishTimestampChanged(qulonglong  value) const;
    void UnitsLoadFinishTimestampMonotonicChanged(qulonglong  value) const;
    void UnitsLoadStartTimestampChanged(qulonglong  value) const;
    void UnitsLoadStartTimestampMonotonicChanged(qulonglong  value) const;
    void UserspaceTimestampChanged(qulonglong  value) const;
    void UserspaceTimestampMonotonicChanged(qulonglong  value) const;
    void VersionChanged(const QString & value) const;
    void VirtualizationChanged(const QString & value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __Systemd1ManagerPrivate *d_ptr;
};

namespace org {
  namespace freedesktop {
    namespace systemd1 {
      typedef ::__Systemd1Manager Manager;
    }
  }
}
#endif
